// -------------------------------------------------------------
// Rational Precision Inc
// All Rights reserved
// Filename:    
//          232dll.h
// File description:
//          Provider a soft interface to connect with DC300,WE6800... by Rs232 port 
// Version: 1.0.0.1
// Create Date: 2002/11/03 
// Author:  atam 
// Modefy Date: 2002/12/23
// Reversion:0
//
// -------------------------------------------------------------

#ifndef _232DLL_
#define _232DLL_
#define export extern "C" _declspec( dllexport)

typedef struct
{
	double X_AXIS;
	double Y_AXIS;
	double Z_AXIS;
}XYZVALUE,*PXYZVALUE;
#define SUCCESS				0
#define ERR_PORTID			-1
#define ERR_OPENPORT		-2
#define ERR_GETDCB			-3
#define ERR_SETDCB			-4
#define ERR_TIMEOUT			-5
#define ERR_DATASUM			-6

#define ERR_NOOPENPORT		-1
#define ERR_MODESETTING		-2
#define ERR_WRITECOMPORT	-3
#define ERR_READCOMPORT		-4


// -------------------------------------------------------------
// Function:
// int Initial232(int Baudrate,int PortID);
//
// Parameters:
//      int Baurate:
//          COM BAUDRATE,4800,9600,14400,19200,28800
//      int PortID:
//          =0: COM1
//          =1: COM2
//          =2: COM3
//          =3: COM4
// Return Value:
//		if no error then return 0, else return the error code
//		SUCCESS:				Success   
//	    ERR_PORTID:     Port Number error			
//      ERR_OPENPORT:	Open Com Port error
//    	ERR_GETDCB:     can't get DCB
//      ERR_SETDCB:     can't set DCB
//		ERR_TIMEOUT:	read or send data by Com occur a timeout	
//		ERR_DATASUM:	there are data error in recieve data
//
// Examples:
//  	Initial232(9600,1);              
//      Baudrate=9600,open "COM2" port
// -------------------------------------------------------------
export int Initial232(int Baudrate,int PortID);

// -------------------------------------------------------------
// Function:
// int GetDataFrom232(int Mode,pXYZVALUE PcbXYZValue, char* pcInBuf);
//
// Parameters:
//      int Mode:
//         use the BCD mode or ASCII mode 
//         = 0: DC3000 BCD MODE;
//         = 1: ASCII MODE;
//         = 2: WE6800 BCD Mode			
//       pXYZVALUE pxyzvalue:
//         the value of the counter readed
//         pxyzvavlue->XVALUE is x axis value;
//         pxyzvavlue->YVALUE is y axis value;
//         pxyzvavlue->ZVALUE is Z axis value;
//       char* pcInBuf:
//			store the data from com.
//			the buffer size is 17 byte in BCD mode,in ASCII mode is 70 byte.
//			if the size is less than the required size ,maybe occur the memory access error	   
//
// Return Value:
//		if no error then return 0, else return the error code
//		0:					Success   
//	    ERR_NOOPENPORT;		port not open
//	    ERR_MODESETTING;    MODE set error
//		ERR_WRITECOMPORT;	Written Com error. To get extended error information, call GetLastError. 
//		ERR_READCOMPORT;	read Com error. To get extended error information, call GetLastError. 
//
// Example:
//	    char buf[100];
//      memset(buf,0,100);
//      ok=GetDataFrom232(0,&xyz,buf);
//           BCD mode,xyz is the counter,buf is the transfer data package
// -------------------------------------------------------------
export int GetDataFrom232(int Mode,PXYZVALUE pcbXYZValue, char* pcInBuf);
#endif

// Example A
/*
	#include "stdlib.h"
    #include "232dll.h"
	
	int ok;
  	Initial232(9600,1);              
    
    XYZVALUE xyz;
	char buf[100];
	memset(buf,0,100);

	ok=GetDataFrom232(0,&xyz,buf);
	printf("%s",buf);
	{
		char x[20],y[20],z[20];
		gcvt(xyz.X_AXIS,10,x);
		gcvt(xyz.Y_AXIS,10,y);
		gcvt(xyz.Z_AXIS,10,z);
		printf("x=  %s\n y=  %s\n z=  %s",x,y,z);
	}
*/